@@ -358,12 +358,11 @@ class LoopRunner(object):
             finally:
                 done_evt.set()
 
-        thread = threading.Thread(target=run_loop,
-                                  name="IO loop")
+        thread = threading.Thread(target=run_loop, name="IO loop")
         thread.daemon = True
         thread.start()
 
-        loop_evt.wait(timeout=1000)
+        loop_evt.wait(timeout=10)
         self._started = True
 
         actual_thread = in_thread[0]
@@ -549,6 +548,7 @@ def key_split(s):
 try:
     from functools import lru_cache
 except ImportError:
+    lru_cache = False
     pass
 else:
     key_split = lru_cache(100000)(key_split)
@@ -1406,6 +1406,10 @@ def has_keyword(func, keyword):
         return keyword in inspect.getargspec(func).args
 
 
+if lru_cache:
+    has_keyword = lru_cache(1000)(has_keyword)
+
+
 # from bokeh.palettes import viridis
 # palette = viridis(18)
 palette = ['#440154', '#471669', '#472A79', '#433C84', '#3C4D8A', '#355D8C',
@@ -1418,3 +1422,11 @@ def color_of(x, palette=palette):
     h = md5(str(x).encode())
     n = int(h.hexdigest()[:8], 16)
     return palette[n % len(palette)]
+
+
+def iscoroutinefunction(f):
+    if gen.is_coroutine_function(f):
+        return True
+    if sys.version_info >= (3, 5) and inspect.iscoroutinefunction(f):
+        return True
+    return False
